@@ -25,31 +25,32 @@ class interface():
         self._pub_committer = None
 
     def assimilate_api(api_list, func, cmd_group=None,
-                       cli_args=None):
+                       cli_args=None, url_args=None):
         cmd_group = func.__name__.split(
             '_') if cmd_group is None else cmd_group
         api_list.append(
             {'fname': func.__name__, 'sig': signature(func),
              'doc': getdoc(func), 'groups': cmd_group,
-             'cli_args': cli_args if cli_args is not None else []})
+             'cli_args': cli_args if cli_args is not None else [],
+             'url_args': url_args if url_args is not None else [], })
         return func
 
-    def public_api(cmd_group=None, cli_args=None):
+    def public_api(cmd_group=None, cli_args=None, url_args=None):
         def decorator_func(func):
             return interface.assimilate_api(
-                interface._public_api, func, cmd_group, cli_args)
+                interface._public_api, func, cmd_group, cli_args, url_args)
         return decorator_func
 
-    def private_api(cmd_group=None, cli_args=None):
+    def private_api(cmd_group=None, cli_args=None, url_args=None):
         def decorator_func(func):
             return interface.assimilate_api(
-                interface._private_api, func, cmd_group, cli_args)
+                interface._private_api, func, cmd_group, cli_args, url_args)
         return decorator_func
 
-    def admin_api(cmd_group=None, cli_args=None):
+    def admin_api(cmd_group=None, cli_args=None, url_args=None):
         def decorator_func(func):
             return interface.assimilate_api(
-                interface._admin_api, func, cmd_group, cli_args)
+                interface._admin_api, func, cmd_group, cli_args, url_args)
         return decorator_func
 
     def cli_api(cmd_group=None, cli_args=None):
